@@ -32,10 +32,14 @@ arch_settings = {
     'sknet50': (SKNetBlock, (3, 4, 6, 3), 32, 4),
     # name: (Block, Layer_planes, radix, groups, width_per_group)
     'resnest50_1s1x64d': (ResNeStBlock, (3, 4, 6, 3), 1, 1, 64),
-    'resnest50_2s1x64d': (ResNeStBlock, (3, 4, 6, 3), 2, 1, 64),
+    'resnest50_fast_2s1x64d': (ResNeStBlock, (3, 4, 6, 3), 2, 1, 64),
     'resnest50_4s1x64d': (ResNeStBlock, (3, 4, 6, 3), 4, 1, 64),
     'resnest50_2s2x40d': (ResNeStBlock, (3, 4, 6, 3), 2, 2, 40),
-    'resnest50_2s2x40d_fast': (ResNeStBlock, (3, 4, 6, 3), 2, 2, 40)
+    'resnest50_fast_2s2x40d': (ResNeStBlock, (3, 4, 6, 3), 2, 2, 40),
+    'resnest50': (ResNeStBlock, (3, 4, 6, 3), 2, 1, 64),
+    'resnest101': (ResNeStBlock, (3, 4, 23, 3), 2, 1, 64),
+    'resnest200': (ResNeStBlock, (3, 24, 36, 3), 2, 1, 64),
+    'resnest269': (ResNeStBlock, (3, 30, 48, 8), 2, 1, 64),
 }
 
 
@@ -58,8 +62,10 @@ def make_stem(in_channels,
     return nn.Sequential(
         conv_layer(in_channels, inner_planes, kernel_size=3, stride=2, padding=1, bias=False),
         norm_layer(inner_planes),
+        act_layer(inplace=True),
         conv_layer(inner_planes, inner_planes, kernel_size=3, stride=1, padding=1, bias=False),
         norm_layer(inner_planes),
+        act_layer(inplace=True),
         conv_layer(inner_planes, base_channels, kernel_size=3, stride=1, padding=1, bias=False),
         norm_layer(base_channels),
         act_layer(inplace=True),
@@ -272,7 +278,7 @@ def build_resnet_d_backbone(cfg):
     act_layer = get_act(cfg)
     zero_init_residual = cfg.MODEL.RECOGNIZER.ZERO_INIT_RESIDUAL
     use_avg = cfg.MODEL.BACKBONE.USE_AVG
-    fast_avg = cfg.MODEL.BACKBONE.FAST_AVG
+    # fast_avg = cfg.MODEL.BACKBONE.FAST_AVG
 
     # for attention
     with_attentions = cfg.MODEL.ATTENTION.WITH_ATTENTIONS
@@ -280,10 +286,9 @@ def build_resnet_d_backbone(cfg):
     attention_type = cfg.MODEL.ATTENTION.ATTENTION_TYPE
 
     radix = 1
+    fast_avg = True if 'fast' in arch else False
     if 'resnest' in arch:
         block_layer, layer_blocks, radix, groups, width_per_group = arch_settings[arch]
-        if 'fast' in arch:
-            fast_avg = True
     else:
         block_layer, layer_blocks, groups, width_per_group = arch_settings[arch]
 
