@@ -26,8 +26,11 @@ class ShuffleNetV2Unit(nn.Module, ABC):
                  act_layer=None,
                  ):
         """
+        refer to Torchvision realization: https://github.com/pytorch/vision/blob/master/torchvision/models/shufflenetv2.py
         when stride = 1, Unit = Channel Shuffle(Concat(Channel Split(Input), Conv(DWConv(Conv(Channel Split(Input))))));
         when stride = 2, Unit = Channel Shuffle(Concat(Conv(DWConv(Input)), Conv(DWConv(Conv(Input)))));
+        official realization (https://github.com/megvii-model/ShuffleNet-Series/blob/master/ShuffleNetV2/blocks.py) has
+         a more ingenious implementation, see [A mismatch in shufflenetv1 about ReLU #53](https://github.com/megvii-model/ShuffleNet-Series/issues/53)
         :param in_channels: 输入通道
         :param out_channels: 输出通道
         :param stride: 步长
@@ -45,15 +48,17 @@ class ShuffleNetV2Unit(nn.Module, ABC):
         if act_layer is None:
             act_layer = nn.ReLU
 
-        self.conv1 = conv_layer(in_channels, out_channels, kernel_size=1, stride=1, padding=0, bias=False)
-        self.norm1 = norm_layer(out_channels)
+        mid_channels = out_channels // 2
+        self.conv1 = conv_layer(in_channels, mid_channels, kernel_size=1, stride=1, padding=0, bias=False)
+        self.norm1 = norm_layer(mid_channels)
 
-        self.conv2 = conv_layer(out_channels, out_channels, kernel_size=3, stride=stride, padding=1, bias=False,
-                                groups=out_channels)
-        self.norm2 = norm_layer(out_channels)
+        self.conv2 = conv_layer(mid_channels, mid_channels, kernel_size=3, stride=stride, padding=1, bias=False,
+                                groups=mid_channels)
+        self.norm2 = norm_layer(mid_channels)
 
-        self.conv3 = conv_layer(out_channels, out_channels, kernel_size=1, stride=1, padding=0, bias=False)
-        self.norm3 = norm_layer(out_channels)
+        self.conv3 = conv_layer(mid_channels, mid_channels, kernel_size=1, stride=1, padding=0,
+                                bias=False)
+        self.norm3 = norm_layer(mid_channels)
 
         self.act = act_layer(inplace=True)
         self.stride = stride
